pitchtools.CounterpointObject
=============================

.. abjad-lineage:: abjad.tools.pitchtools.CounterpointObject.CounterpointObject.CounterpointObject

.. autoclass:: abjad.tools.pitchtools.CounterpointObject.CounterpointObject.CounterpointObject
   :noindex:

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.pitchtools.CounterpointObject.CounterpointObject.CounterpointObject.storage_format
   :noindex:

Special Methods
---------------

.. automethod:: abjad.tools.pitchtools.CounterpointObject.CounterpointObject.CounterpointObject.__eq__
   :noindex:

.. automethod:: abjad.tools.pitchtools.CounterpointObject.CounterpointObject.CounterpointObject.__ge__
   :noindex:

.. automethod:: abjad.tools.pitchtools.CounterpointObject.CounterpointObject.CounterpointObject.__gt__
   :noindex:

.. automethod:: abjad.tools.pitchtools.CounterpointObject.CounterpointObject.CounterpointObject.__le__
   :noindex:

.. automethod:: abjad.tools.pitchtools.CounterpointObject.CounterpointObject.CounterpointObject.__lt__
   :noindex:

.. automethod:: abjad.tools.pitchtools.CounterpointObject.CounterpointObject.CounterpointObject.__ne__
   :noindex:

.. automethod:: abjad.tools.pitchtools.CounterpointObject.CounterpointObject.CounterpointObject.__repr__
   :noindex:
